@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2011-2018, Cédric Krier
+# Copyright (c) 2011-2020, Cédric Krier
 # Copyright (c) 2013-2014, Nicolas Évrard
-# Copyright (c) 2011-2018, B2CK
+# Copyright (c) 2011-2020, B2CK
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@ from threading import local, currentThread
 from collections import defaultdict
 from itertools import chain
 
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 __all__ = ['Flavor', 'Table', 'Values', 'Literal', 'Column', 'Join',
     'Asc', 'Desc', 'NullsFirst', 'NullsLast', 'format2numeric']
 
@@ -637,8 +637,8 @@ class Select(FromItem, SelectQuery):
         p = []
         with AliasManager():
             # Set alias to window function to skip their params
-            for window_function in self.windows:
-                window_function.alias
+            for window in self.windows:
+                window.alias
 
             p.extend(self._with_params())
             for column in chain(self.distinct_on or (), self.columns):
@@ -657,8 +657,8 @@ class Select(FromItem, SelectQuery):
                     p.extend(expression.params)
             if self.having:
                 p.extend(self.having.params)
-            for window_function in self.windows:
-                p.extend(window_function.window.params)
+            for window in self.windows:
+                p.extend(window.params)
         return tuple(p)
 
 
