@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2011-2015, Cédric Krier
-# Copyright (c) 2011-2015, B2CK
+# Copyright (c) 2011-2018, Cédric Krier
+# Copyright (c) 2011-2018, B2CK
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,24 +27,48 @@
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
-from sql import Expression, Window
+from sql import Expression, Window, Flavor, Literal
 
 __all__ = ['Avg', 'BitAnd', 'BitOr', 'BoolAnd', 'BoolOr', 'Count', 'Every',
     'Max', 'Min', 'Stddev', 'Sum', 'Variance']
 
 
 class Aggregate(Expression):
-    __slots__ = ('expression', '_within', '_filter', '_window')
+    __slots__ = ('expression', '_distinct', '_order_by', '_within',
+        '_filter', '_window')
     _sql = ''
 
-    def __init__(self, expression, within=None, filter_=None, window=None):
-        # TODO order_by
+    def __init__(self, expression, distinct=False, order_by=None, within=None,
+            filter_=None, window=None):
         super(Aggregate, self).__init__()
         self.expression = expression
+        self.distinct = distinct
+        self.order_by = order_by
         self.within = within
         self.filter_ = filter_
         self.window = window
 
+    @property
+    def distinct(self):
+        return self._distinct
+
+    @distinct.setter
+    def distinct(self, value):
+        assert isinstance(value, bool)
+        self._distinct = value
+
+    @property
+    def order_by(self):
+        return self._order_by
+
+    @order_by.setter
+    def order_by(self, value):
+        if value is not None:
+            if isinstance(value, Expression):
+                value = [value]
+            assert all(isinstance(col, Expression) for col in value)
+        self._order_by = value
+
     @property
     def within(self):
         return self._within
@@ -78,28 +102,56 @@ class Aggregate(Expression):
             assert isinstance(value, Window)
         self._window = value
 
+    @property
+    def _case_expression(self):
+        return self.expression
+
     def __str__(self):
-        aggregate = '%s(%s)' % (self._sql, self.expression)
+        quantifier = 'DISTINCT ' if self.distinct else ''
+        has_filter = Flavor.get().filter_
+        expression = self.expression
+        if self.filter_ and not has_filter:
+            from sql.conditionals import Case
+            expression = Case((self.filter_, self._case_expression))
+        order_by = ''
+        if self.order_by:
+            order_by = ' ORDER BY %s' % ', '.join(map(str, self.order_by))
+        aggregate = '%s(%s%s%s)' % (
+            self._sql, quantifier, expression, order_by)
         within = ''
         if self.within:
             within = (' WITHIN GROUP (ORDER BY %s)'
                 % ', '.join(map(str, self.within)))
         filter_ = ''
-        if self.filter_:
+        if self.filter_ and has_filter:
             filter_ = ' FILTER (WHERE %s)' % self.filter_
         window = ''
         if self.window:
-            window = ' OVER "%s"' % self.window.alias
+            if self.window.has_alias:
+                window = ' OVER "%s"' % self.window.alias
+            else:
+                window = ' OVER (%s)' % self.window
         return aggregate + within + filter_ + window
 
     @property
     def params(self):
-        p = list(self.expression.params)
+        has_filter = Flavor.get().filter_
+        p = []
+        if self.filter_ and not has_filter:
+            p.extend(self.filter_.params)
+            p.extend(self._case_expression.params)
+        else:
+            p.extend(self.expression.params)
+        if self.order_by:
+            for expression in self.order_by:
+                p.extend(expression.params)
         if self.within:
             for expression in self.within:
                 p.extend(expression.params)
-        if self.filter_:
+        if self.filter_ and has_filter:
             p.extend(self.filter_.params)
+        if self.window and not self.window.has_alias:
+            p.extend(self.window.params)
         return tuple(p)
 
 
@@ -132,6 +184,14 @@ class Count(Aggregate):
     __slots__ = ()
     _sql = 'COUNT'
 
+    @property
+    def _case_expression(self):
+        expression = super(Count, self)._case_expression
+        if (isinstance(self.expression, Literal)
+                and expression.value == '*'):
+            expression = Literal(1)
+        return expression
+
 
 class Every(Aggregate):
     __slots__ = ()
