@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2011-2015, Cédric Krier
-# Copyright (c) 2011-2015, B2CK
+# Copyright (c) 2011-2018, Cédric Krier
+# Copyright (c) 2011-2018, B2CK
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -30,6 +30,11 @@ from itertools import chain
 
 from sql import Expression, Flavor, FromItem, Window
 
+try:
+    basestring
+except NameError:
+    basestring = str
+
 __all__ = ['Abs', 'Cbrt', 'Ceil', 'Degrees', 'Div', 'Exp', 'Floor', 'Ln',
     'Log', 'Mod', 'Pi', 'Power', 'Radians', 'Random', 'Round', 'SetSeed',
     'Sign', 'Sqrt', 'Trunc', 'WidthBucket',
@@ -472,15 +477,21 @@ class AtTimeZone(Function):
         Mapping = flavor.function_mapping.get(self.__class__)
         if Mapping:
             return str(Mapping(self.field, self.zone))
-        param = flavor.param
-        return '%s AT TIME ZONE %s' % (str(self.field), param)
+        if isinstance(self.zone, Expression):
+            zone = str(self.zone)
+        else:
+            zone = flavor.param
+        return '%s AT TIME ZONE %s' % (str(self.field), zone)
 
     @property
     def params(self):
         Mapping = Flavor.get().function_mapping.get(self.__class__)
         if Mapping:
             return Mapping(self.field, self.zone).params
-        return self.field.params + (self.zone,)
+        if isinstance(self.zone, Expression):
+            return self.field.params + self.zone.params
+        else:
+            return self.field.params + (self.zone,)
 
 
 class WindowFunction(Function):
@@ -517,7 +528,10 @@ class WindowFunction(Function):
         filter_ = ''
         if self.filter_:
             filter_ = ' FILTER (WHERE %s)' % self.filter_
-        over = ' OVER "%s"' % self.window.alias
+        if self.window.has_alias:
+            over = ' OVER "%s"' % self.window.alias
+        else:
+            over = ' OVER (%s)' % self.window
         return function + filter_ + over
 
     @property
@@ -525,6 +539,8 @@ class WindowFunction(Function):
         p = list(super(WindowFunction, self).params)
         if self.filter_:
             p.extend(self.filter_.params)
+        if not self.window.has_alias:
+            p.extend(self.window.params)
         return tuple(p)
 
 
